@@ -5,8 +5,7 @@ string Cron::hmac(string const &passPhrase)
     HMacBuf hmacbuf(passPhrase, "sha256");
 
     ostream out(&hmacbuf);
-    out << passPhrase;
-    hmacbuf.close();
+    out << passPhrase << eoi;
 
     string hash = hmacbuf.hash();
 
